==> r-cran-ggplot2_3.5.1+dfsg.orig.tar.xz: ggplot2/tests/testthat/_snaps/prohibited-functions.md <==
# No new argument names use underscores

    Code
      underscore_args
    Output
      $as_labeller
      [1] "multi_line"
      
      $binned_scale
      [1] "scale_name"
      
      $calc_element
      [1] "skip_blank"
      
      $continuous_scale
      [1] "scale_name"   "minor_breaks"
      
      $coord_munch
      [1] "segment_length" "is_closed"     
      
      $coord_radial
      [1] "r_axis_inside" "rotate_angle" 
      
      $coord_sf
      [1] "default_crs"     "label_graticule" "label_axes"      "lims_method"    
      
      $datetime_scale
      [1] "minor_breaks"      "date_breaks"       "date_labels"      
      [4] "date_minor_breaks"
      
      $discrete_scale
      [1] "scale_name"
      
      $geom_density2d
      [1] "contour_var"
      
      $geom_density2d_filled
      [1] "contour_var"
      
      $geom_density_2d
      [1] "contour_var"
      
      $geom_density_2d_filled
      [1] "contour_var"
      
      $geom_label
      [1] "nudge_x" "nudge_y"
      
      $geom_sf_label
      [1] "nudge_x" "nudge_y"
      
      $geom_sf_text
      [1] "nudge_x"       "nudge_y"       "check_overlap"
      
      $geom_text
      [1] "nudge_x"       "nudge_y"       "check_overlap"
      
      $geom_violin
      [1] "draw_quantiles"
      
      $ggplot_add
      [1] "object_name"
      
      $ggproto
      [1] "_class"   "_inherit"
      
      $guide_axis_logticks
      [1] "prescale_base"  "negative_small" "short_theme"   
      
      $guide_colorbar
      [1] "available_aes"
      
      $guide_colorsteps
      [1] "available_aes"
      
      $guide_colourbar
      [1] "available_aes"
      
      $guide_coloursteps
      [1] "available_aes"
      
      $guide_geom
      [1] "default_mapping"
      
      $guide_merge
      [1] "new_guide"
      
      $guide_transform
      [1] "panel_params"
      
      $has_flipped_aes
      [1] "main_is_orthogonal"  "range_is_orthogonal" "group_has_equal"    
      [4] "main_is_continuous"  "main_is_optional"   
      
      $label_both
      [1] "multi_line"
      
      $label_context
      [1] "multi_line"
      
      $label_parsed
      [1] "multi_line"
      
      $label_value
      [1] "multi_line"
      
      $label_wrap_gen
      [1] "multi_line"
      
      $labeller
      [1] ".multi_line"
      
      $labs
      [1] "alt_insight"
      
      $layer
      [1] "key_glyph"   "layer_class"
      
      $max_height
      [1] "value_only"
      
      $max_width
      [1] "value_only"
      
      $new_guide
      [1] "available_aes"
      
      $register_theme_elements
      [1] "element_tree"
      
      $reset_theme_settings
      [1] "reset_current"
      
      $scale_size_area
      [1] "max_size"
      
      $scale_size_binned_area
      [1] "max_size"
      
      $scale_x_continuous
      [1] "minor_breaks"
      
      $scale_x_date
      [1] "date_breaks"       "date_labels"       "minor_breaks"     
      [4] "date_minor_breaks"
      
      $scale_x_datetime
      [1] "date_breaks"       "date_labels"       "minor_breaks"     
      [4] "date_minor_breaks"
      
      $scale_x_time
      [1] "minor_breaks"
      
      $scale_y_continuous
      [1] "minor_breaks"
      
      $scale_y_date
      [1] "date_breaks"       "date_labels"       "minor_breaks"     
      [4] "date_minor_breaks"
      
      $scale_y_datetime
      [1] "date_breaks"       "date_labels"       "minor_breaks"     
      [4] "date_minor_breaks"
      
      $scale_y_time
      [1] "minor_breaks"
      
      $sf_transform_xy
      [1] "target_crs"          "source_crs"          "authority_compliant"
      
      $stage
      [1] "after_stat"  "after_scale"
      
      $stat_density2d
      [1] "contour_var"
      
      $stat_density2d_filled
      [1] "contour_var"
      
      $stat_density_2d
      [1] "contour_var"
      
      $stat_density_2d_filled
      [1] "contour_var"
      
      $theme_bw
      [1] "base_size"      "base_family"    "base_line_size" "base_rect_size"
      
      $theme_classic
      [1] "base_size"      "base_family"    "base_line_size" "base_rect_size"
      
      $theme_dark
      [1] "base_size"      "base_family"    "base_line_size" "base_rect_size"
      
      $theme_gray
      [1] "base_size"      "base_family"    "base_line_size" "base_rect_size"
      
      $theme_grey
      [1] "base_size"      "base_family"    "base_line_size" "base_rect_size"
      
      $theme_light
      [1] "base_size"      "base_family"    "base_line_size" "base_rect_size"
      
      $theme_linedraw
      [1] "base_size"      "base_family"    "base_line_size" "base_rect_size"
      
      $theme_minimal
      [1] "base_size"      "base_family"    "base_line_size" "base_rect_size"
      
      $theme_test
      [1] "base_size"      "base_family"    "base_line_size" "base_rect_size"
      
      $theme_void
      [1] "base_size"      "base_family"    "base_line_size" "base_rect_size"
      
      $transform_position
      [1] "trans_x" "trans_y"
      
      $translate_shape_string
      [1] "shape_string"

==> r-cran-ggplot2_4.0.1+dfsg.orig.tar.xz: ggplot2/tests/testthat/_snaps/prohibited-functions.md <==
# No new argument names use underscores

    Code
      underscore_args
    Output
      $as_labeller
      [1] "multi_line"
      
      $binned_scale
      [1] "scale_name"
      
      $calc_element
      [1] "skip_blank"
      
      $class_ggplot
      [1] "plot_env"
      
      $continuous_scale
      [1] "scale_name"   "minor_breaks"
      
      $coord_munch
      [1] "segment_length" "is_closed"     
      
      $coord_radial
      [1] "r_axis_inside" "rotate_angle" 
      
      $coord_sf
      [1] "default_crs"     "label_graticule" "label_axes"      "lims_method"    
      
      $datetime_scale
      [1] "minor_breaks"      "date_breaks"       "date_labels"      
      [4] "date_minor_breaks"
      
      $discrete_scale
      [1] "scale_name"   "minor_breaks"
      
      $geom_density2d
      [1] "contour_var"
      
      $geom_density2d_filled
      [1] "contour_var"
      
      $geom_density_2d
      [1] "contour_var"
      
      $geom_density_2d_filled
      [1] "contour_var"
      
      $geom_sf_text
      [1] "check_overlap"
      
      $geom_text
      [1] "check_overlap"
      
      $geom_violin
      [1] "draw_quantiles"
      
      $ggproto
      [1] "_class"   "_inherit"
      
      $guide_axis_logticks
      [1] "prescale_base"  "negative_small" "short_theme"   
      
      $guide_colorbar
      [1] "available_aes"
      
      $guide_colorsteps
      [1] "available_aes"
      
      $guide_colourbar
      [1] "available_aes"
      
      $guide_coloursteps
      [1] "available_aes"
      
      $guide_geom
      [1] "default_mapping"
      
      $guide_merge
      [1] "new_guide"
      
      $guide_transform
      [1] "panel_params"
      
      $has_flipped_aes
      [1] "main_is_orthogonal"  "range_is_orthogonal" "group_has_equal"    
      [4] "main_is_continuous"  "main_is_optional"   
      
      $label_both
      [1] "multi_line"
      
      $label_context
      [1] "multi_line"
      
      $label_parsed
      [1] "multi_line"
      
      $label_value
      [1] "multi_line"
      
      $label_wrap_gen
      [1] "multi_line"
      
      $labeller
      [1] ".multi_line"
      
      $labs
      [1] "alt_insight"
      
      $layer
      [1] "key_glyph"   "layer_class"
      
      $max_height
      [1] "value_only"
      
      $max_width
      [1] "value_only"
      
      $new_guide
      [1] "available_aes"
      
      $register_theme_elements
      [1] "element_tree"
      
      $reset_theme_settings
      [1] "reset_current"
      
      $scale_size_area
      [1] "max_size"
      
      $scale_size_binned_area
      [1] "max_size"
      
      $scale_x_continuous
      [1] "minor_breaks"
      
      $scale_x_date
      [1] "date_breaks"       "date_labels"       "minor_breaks"     
      [4] "date_minor_breaks"
      
      $scale_x_datetime
      [1] "date_breaks"       "date_labels"       "minor_breaks"     
      [4] "date_minor_breaks"
      
      $scale_x_time
      [1] "date_breaks"       "minor_breaks"      "date_minor_breaks"
      [4] "date_labels"      
      
      $scale_y_continuous
      [1] "minor_breaks"
      
      $scale_y_date
      [1] "date_breaks"       "date_labels"       "minor_breaks"     
      [4] "date_minor_breaks"
      
      $scale_y_datetime
      [1] "date_breaks"       "date_labels"       "minor_breaks"     
      [4] "date_minor_breaks"
      
      $scale_y_time
      [1] "date_breaks"       "minor_breaks"      "date_minor_breaks"
      [4] "date_labels"      
      
      $sf_transform_xy
      [1] "target_crs"          "source_crs"          "authority_compliant"
      
      $stage
      [1] "after_stat"  "after_scale"
      
      $stat_density2d
      [1] "contour_var"
      
      $stat_density2d_filled
      [1] "contour_var"
      
      $stat_density_2d
      [1] "contour_var"
      
      $stat_density_2d_filled
      [1] "contour_var"
      
      $theme_bw
      [1] "base_size"      "base_family"    "header_family"  "base_line_size"
      [5] "base_rect_size"
      
      $theme_classic
      [1] "base_size"      "base_family"    "header_family"  "base_line_size"
      [5] "base_rect_size"
      
      $theme_dark
      [1] "base_size"      "base_family"    "header_family"  "base_line_size"
      [5] "base_rect_size"
      
      $theme_gray
      [1] "base_size"      "base_family"    "header_family"  "base_line_size"
      [5] "base_rect_size"
      
      $theme_grey
      [1] "base_size"      "base_family"    "header_family"  "base_line_size"
      [5] "base_rect_size"
      
      $theme_light
      [1] "base_size"      "base_family"    "header_family"  "base_line_size"
      [5] "base_rect_size"
      
      $theme_linedraw
      [1] "base_size"      "base_family"    "header_family"  "base_line_size"
      [5] "base_rect_size"
      
      $theme_minimal
      [1] "base_size"      "base_family"    "header_family"  "base_line_size"
      [5] "base_rect_size"
      
      $theme_test
      [1] "base_size"      "base_family"    "header_family"  "base_line_size"
      [5] "base_rect_size"
      
      $theme_void
      [1] "base_size"      "base_family"    "header_family"  "base_line_size"
      [5] "base_rect_size"
      
      $transform_position
      [1] "trans_x" "trans_y"
      
      $translate_shape_string
      [1] "shape_string"
